( cd usr/lib ; rm -rf libcolorblind.so )
( cd usr/lib ; ln -sf libcolorblind.so.0.0.1 libcolorblind.so )
( cd usr/lib ; rm -rf libcolorblind.so.0 )
( cd usr/lib ; ln -sf libcolorblind.so.0.0.1 libcolorblind.so.0 )
